@@ -8,14 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_eks._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-kubesphere", "0.0.193", __name__[0:-6], "cdk-kubesphere@0.0.193.jsii.tgz"
+    "cdk-kubesphere", "2.0.9", __name__[0:-6], "cdk-kubesphere@2.0.9.jsii.tgz"
 )
 
 __all__ = [
